Summary:     oneAPI Threading Building Blocks (oneTBB)
Name:        tbb
Version:     2020.3
Release:     3%{?dist}
License:     ASL 2.0
URL:         https://github.com/oneapi-src/oneTBB
Source0:     https://github.com/intel/tbb/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:     tbb.pc
Source2:     tbbmalloc.pc
Source3:     tbbmalloc_proxy.pc

Patch0001:   tbb-2019-dont-snip-Wall.patch
Patch3000:   tbb-2020-attributes.patch
Patch3001:   tbb-2019-test-task-scheduler-init.patch
Patch3002:   tbb-mark-empty_task-execute-with-gnu-used.patch

BuildRequires: cmake gcc-c++ make
BuildRequires: python3-devel swig

%description
oneTBB is a flexible C++ library that simplifies the work
of adding parallelism to complex applications, even if you
are not a threading expert.

%package devel
Summary:  The Threading Building Blocks C++ headers and shared development libraries
Requires: %{name} = %{version}-%{release}

%description devel
Header files and shared object symlinks for the Threading Building
Blocks (TBB) C++ libraries.

%package -n python3-%{name}
Summary: Python 3 TBB module

%description -n python3-%{name}
Python 3 TBB module.


%prep
%autosetup -p1 -n oneTBB-%{version}
sed -i 's/"`hostname -s`" ("`uname -m`"/opencloudosbuild (%{_arch}/' build/version_info_linux.sh
sed -i "s/-fPIC/& -Wl,--as-needed/" build/linux.gcc.inc
sed -i 's,env python,python3,' python/TBB.py python/tbb/__*.py
sed -i '/^#!/d' python/tbb/{pool,test}.py


%build
%make_build tbb_build_prefix=obj stdver=c++14 \
    CXXFLAGS="%{optflags} -DUSE_PTHREAD" \
    LDFLAGS="%{build_ldflags} -lpthread"

. build/obj_release/tbbvars.sh
pushd python
%make_build -C rml stdver=c++14 \
    CPLUS_FLAGS="%{optflags} -DUSE_PTHREAD" \
    LDFLAGS="%{build_ldflags} -lpthread"
cp -p rml/libirml.so* .
%py3_build
popd


%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}

pushd build/obj_release
    for file in libtbb{,malloc{,_proxy}}; do
        install -p -D -m 755 ${file}.so.2 %{buildroot}%{_libdir}
        ln -s $file.so.2 %{buildroot}%{_libdir}/$file.so
    done
popd

pushd include
    find tbb -type f ! -name \*.htm\* -exec \
        install -p -D -m 644 {} %{buildroot}%{_includedir}/{} \
    \;
popd

for file in %{SOURCE1} %{SOURCE2} %{SOURCE3}; do
    install -p -D -m 644 ${file} %{buildroot}%{_libdir}/pkgconfig/$(basename ${file})
done

mkdir -p %{buildroot}%{_includedir}/rml
cp -p src/rml/include/*.h %{buildroot}%{_includedir}/rml

. build/obj_release/tbbvars.sh
pushd python
%py3_install
chmod a+x %{buildroot}%{python3_sitearch}/TBB.py
chmod a+x %{buildroot}%{python3_sitearch}/tbb/__*.py
cp -p libirml.so.1 %{buildroot}%{_libdir}
ln -s libirml.so.1 %{buildroot}%{_libdir}/libirml.so
popd

cmake \
  -DINSTALL_DIR=%{buildroot}%{_libdir}/cmake/TBB \
  -DSYSTEM_NAME=Linux \
  -DLIB_REL_PATH=../.. \
  -P cmake/tbb_config_installer.cmake


%check
sed -i '/test_task_scheduler_observer/d' build/Makefile.test
make test tbb_build_prefix=obj stdver=c++14 CXXFLAGS="%%{optflags}"


%files
%license LICENSE
%doc doc/Release_Notes.txt README.md
%{_libdir}/libtbb.so.2
%{_libdir}/libtbbmalloc.so.2
%{_libdir}/libtbbmalloc_proxy.so.2
%{_libdir}/libirml.so.1

%files devel
%doc CHANGES cmake/README.rst
%{_includedir}/rml/
%{_includedir}/tbb/
%{_libdir}/*.so
%{_libdir}/cmake/TBB/
%{_libdir}/pkgconfig/*.pc

%files -n python3-%{name}
%{python3_sitearch}/TBB*
%{python3_sitearch}/tbb/
%{python3_sitearch}/__pycache__/TBB*

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2020.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2020.3-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Sep 20 2022 ZoeDong <zoedong@tencent.com> - 2020.3-1
- Initial build
